#include "NavigationStackConfig.h"

#include <RobotAPI/interface/aron/Aron.h>

#include "Navigation/libraries/core/constants.h"

namespace armarx::nav::client
{
    aron::data::AronDictPtr NavigationStackConfig::toAron() const
    {
        return dict.toAronDictPtr();
    }

    NavigationStackConfig&
    NavigationStackConfig::configureGlobalPlanner(const glob_plan::GlobalPlannerParams& params)
    {
        aron::datanavigator::DictNavigatorPtr element(new aron::datanavigator::DictNavigator);
        element->addElement(core::NAME_KEY,
                            std::make_shared<aron::datanavigator::StringNavigator>(
                                glob_plan::AlgorithmNames.to_name(params.algorithm())));
        element->addElement(core::PARAMS_KEY, params.toAron());

        dict.addElement(core::GLOBAL_PLANNER, element);

        return *this;
    }

    NavigationStackConfig& NavigationStackConfig::configureLocalPlanner(const loc_plan::LocalPlannerParams& params)
    {
        aron::datanavigator::DictNavigatorPtr element(new aron::datanavigator::DictNavigator);
        element->addElement(core::NAME_KEY,
                            std::make_shared<aron::datanavigator::StringNavigator>(
                                loc_plan::AlgorithmNames.to_name(params.algorithm())));
        element->addElement(core::PARAMS_KEY, params.toAron());

        dict.addElement(core::LOCAL_PLANNER, element);

        return *this;
    }

    NavigationStackConfig& NavigationStackConfig::configureTrajectoryController(const traj_ctrl::TrajectoryControllerParams& params)
    {
        aron::datanavigator::DictNavigatorPtr element(new aron::datanavigator::DictNavigator);
        element->addElement(core::NAME_KEY,
                            std::make_shared<aron::datanavigator::StringNavigator>(
                                traj_ctrl::AlgorithmNames.to_name(params.algorithm())));
        element->addElement(core::PARAMS_KEY, params.toAron());

        dict.addElement(core::TRAJECTORY_CONTROLLER, element);

        return *this;
    }

    NavigationStackConfig& NavigationStackConfig::configureSafetyController(const safe_ctrl::SafetyControllerParams& params)
    {
        aron::datanavigator::DictNavigatorPtr element(new aron::datanavigator::DictNavigator);
        element->addElement(core::NAME_KEY,
                            std::make_shared<aron::datanavigator::StringNavigator>(
                                safe_ctrl::AlgorithmNames.to_name(params.algorithm())));
        element->addElement(core::PARAMS_KEY, params.toAron());

        dict.addElement(core::SAFETY_CONTROLLER, element);

        return *this;
    }
} // namespace armarx::nav::client
