#include "Point2Point.h"

#include <memory>

#include <Eigen/src/Geometry/Transform.h>

#include <VirtualRobot/Robot.h>

#include <ArmarXCore/interface/serialization/Eigen/Eigen_fdi.h>

#include "Navigation/libraries/core/Trajectory.h"
#include "Navigation/libraries/core/types.h"
#include "Navigation/libraries/global_planning/GlobalPlanner.h"
#include "Navigation/libraries/global_planning/core.h"

namespace armarx::nav::glob_plan
{

    // Point2PointParams

    Algorithms Point2PointParams::algorithm() const
    {
        return Algorithms::Point2Point;
    }

    aron::datanavigator::DictNavigatorPtr Point2PointParams::toAron() const
    {
        return nullptr; // TODO implement
    }

    Point2PointParams Point2PointParams::FromAron(const aron::datanavigator::DictNavigatorPtr& dict)
    {
        return Point2PointParams(); // TODO implement
    }

    // Point2Point

    Point2Point::Point2Point(const Point2Point::Params& params, const core::Scene& ctx) :
        GlobalPlanner(ctx), params(params)
    {
    }

    core::TrajectoryPtr Point2Point::plan(const core::Pose& goal)
    {
        std::vector<core::TrajectoryPoint> trajectory;

        if (params.includeStartPose)
        {
            trajectory.push_back(core::TrajectoryPoint
            {
                .waypoint = core::Waypoint{.pose = core::Pose(scene.robot->getGlobalPose())},
                .twist = {.linear = Eigen::Vector3f::Zero(), .angular = Eigen::Vector3f::Zero()}});
        }

        trajectory.push_back(core::TrajectoryPoint
        {
            .waypoint = core::Waypoint{.pose = goal},
            .twist = {.linear = Eigen::Vector3f::Zero(), .angular = Eigen::Vector3f::Zero()}});

        return std::make_shared<core::Trajectory>(trajectory);
    }

} // namespace armarx::nav::glob_plan
